@@ -2,7 +2,13 @@ from .dbserver.data_manager import data_manager
 
 
 class Data(object):
-    Base = None
+    try:
+        from config.db_config import db_config
+        if isinstance(db_config,dict):
+            Base = data_manager(db_config)
+    except:
+        print('Did not find a db config file, need run Data.init(db_config) manually...')
+        Base = data_manager(db_config)
 
     @staticmethod
     def init(db_config):
